==> haskell-safecopy-0.10.4.3-43-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-safecopy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 safecopy
version:              0.10.4.3
visibility:           public
id:                   safecopy-0.10.4.3-9qc8t0Hg9b8BMKzIufxIfP
key:                  safecopy-0.10.4.3-9qc8t0Hg9b8BMKzIufxIfP
license:              LicenseRef-PublicDomain
maintainer:           Lemmih <lemmih@gmail.com>, David Fox <dsf@seereason.com>
author:               David Himmelstrup, Felipe Lessa
homepage:             https://github.com/acid-state/safecopy
synopsis:             Binary serialization with version control.
description:
    An extension to Data.Serialize with built-in version control.

category:             Data, Parsing
abi:                  e3969055b6e1ac512420b984d5501794
exposed:              True
exposed-modules:      Data.SafeCopy Data.SafeCopy.Internal
hidden-modules:
    Data.SafeCopy.Instances Data.SafeCopy.SafeCopy Data.SafeCopy.Derive

import-dirs:          /usr/lib/ghc-9.4.8/site-local/safecopy-0.10.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/safecopy-0.10.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/safecopy-0.10.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-safecopy
hs-libraries:         HSsafecopy-0.10.4.3-9qc8t0Hg9b8BMKzIufxIfP
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT containers-0.6.7
    generic-data-1.1.0.2-60j4is5zPjnALoBvjQr2EL
    old-time-1.1.0.4-7kNg8VzooGoExH4yeT9sv9 template-haskell-2.19.0.0
    text-2.0.2 time-1.12.2 transformers-0.5.6.2
    vector-0.13.2.0-9W9rHKyBrY08EKASla5WO0

haddock-interfaces:   /usr/share/doc/haskell-safecopy/html/safecopy.haddock
haddock-html:         /usr/share/doc/haskell-safecopy/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-safecopy-0.10.4.3-44-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-safecopy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 safecopy
version:              0.10.4.3
visibility:           public
id:                   safecopy-0.10.4.3-EoTEKFah6xJPNYvoTvGGE
key:                  safecopy-0.10.4.3-EoTEKFah6xJPNYvoTvGGE
license:              LicenseRef-PublicDomain
maintainer:           Lemmih <lemmih@gmail.com>, David Fox <dsf@seereason.com>
author:               David Himmelstrup, Felipe Lessa
homepage:             https://github.com/acid-state/safecopy
synopsis:             Binary serialization with version control.
description:
    An extension to Data.Serialize with built-in version control.

category:             Data, Parsing
abi:                  e0d74c555548dc92c4739313bb352e87
exposed:              True
exposed-modules:      Data.SafeCopy Data.SafeCopy.Internal
hidden-modules:
    Data.SafeCopy.Instances Data.SafeCopy.SafeCopy Data.SafeCopy.Derive

import-dirs:          /usr/lib/ghc-9.4.8/site-local/safecopy-0.10.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/safecopy-0.10.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/safecopy-0.10.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-safecopy
hs-libraries:         HSsafecopy-0.10.4.3-EoTEKFah6xJPNYvoTvGGE
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT containers-0.6.7
    generic-data-1.1.0.2-CLsf4kJPqoj92xRLAh15dT
    old-time-1.1.0.4-7kNg8VzooGoExH4yeT9sv9 template-haskell-2.19.0.0
    text-2.0.2 time-1.12.2 transformers-0.5.6.2
    vector-0.13.2.0-24VaMY7coOLw3wI0c1W3K

haddock-interfaces:   /usr/share/doc/haskell-safecopy/html/safecopy.haddock
haddock-html:         /usr/share/doc/haskell-safecopy/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
